@@ -1,6 +1,6 @@
 import aiohttp
 
-from core import exceptions
+from Core import UnableToAccessApi
 
 
 async def text_to_handwriting(
@@ -15,4 +15,4 @@ async def text_to_handwriting(
                     file.write(await response.read())
                     file.close()
             elif 400 <= status_code <= 599:
-                raise exceptions.UnableToAccessApi("Unable to access Pywhatkit api right now")
+                raise UnableToAccessApi("Unable to access Pywhatkit api right now")
